@@ -5,31 +5,24 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 )
 
 type Azd struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
 	azdConfig
 }
 
 type azdConfig struct {
-	Version            int    `json:"version"`
 	DefaultEnvironment string `json:"defaultEnvironment"`
+	Version            int    `json:"version"`
 }
 
 func (t *Azd) Template() string {
 	return " \uebd8 {{ .DefaultEnvironment }} "
 }
 
-func (t *Azd) Init(props properties.Properties, env runtime.Environment) {
-	t.props = props
-	t.env = env
-}
-
 func (t *Azd) Enabled() bool {
 	var parentFilePath string
 
@@ -42,7 +35,7 @@ func (t *Azd) Enabled() bool {
 	}
 
 	if len(parentFilePath) == 0 {
-		t.env.Debug("No .azure folder found in parent directories")
+		log.Debug("no .azure folder found in parent directories")
 		return false
 	}
 
