@@ -2,17 +2,14 @@ package segments
 
 import (
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/battery"
 )
 
 type Battery struct {
-	props properties.Properties
-	env   runtime.Environment
-
-	*battery.Info
+	base
 	Error string
 	Icon  string
+	battery.Info
 }
 
 const (
@@ -36,19 +33,20 @@ func (b *Battery) Enabled() bool {
 		return false
 	}
 
-	var err error
-	b.Info, err = b.env.BatteryState()
+	info, err := b.env.BatteryState()
 
 	if !b.enabledWhileError(err) {
 		return false
 	}
 
+	b.Info = *info
+
 	// case on computer without batteries(no error, empty array)
-	if err == nil && b.Info == nil {
+	if err == nil && b.Percentage == 0 {
 		return false
 	}
 
-	switch b.Info.State {
+	switch b.State {
 	case battery.Discharging:
 		b.Icon = b.props.GetString(DischargingIcon, "")
 	case battery.NotCharging:
@@ -83,8 +81,3 @@ func (b *Battery) enabledWhileError(err error) bool {
 	b.State = battery.Full
 	return true
 }
-
-func (b *Battery) Init(props properties.Properties, env runtime.Environment) {
-	b.props = props
-	b.env = env
-}
