@@ -4,26 +4,24 @@ import (
 	"encoding/json"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
 type Wakatime struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
 	wtData
 }
 
 type wtTotals struct {
-	Seconds float64 `json:"seconds"`
 	Text    string  `json:"text"`
+	Seconds float64 `json:"seconds"`
 }
 
 type wtData struct {
-	CumulativeTotal wtTotals `json:"cumulative_total"`
 	Start           string   `json:"start"`
 	End             string   `json:"end"`
+	CumulativeTotal wtTotals `json:"cumulative_total"`
 }
 
 func (w *Wakatime) Template() string {
@@ -40,17 +38,6 @@ func (w *Wakatime) setAPIData() error {
 	if err != nil {
 		return err
 	}
-	cacheTimeout := w.props.GetInt(properties.CacheTimeout, properties.DefaultCacheTimeout)
-	if cacheTimeout > 0 {
-		// check if data stored in cache
-		if val, found := w.env.Cache().Get(url); found {
-			err := json.Unmarshal([]byte(val), &w.wtData)
-			if err != nil {
-				return err
-			}
-			return nil
-		}
-	}
 
 	httpTimeout := w.props.GetInt(properties.HTTPTimeout, properties.DefaultHTTPTimeout)
 
@@ -58,14 +45,12 @@ func (w *Wakatime) setAPIData() error {
 	if err != nil {
 		return err
 	}
+
 	err = json.Unmarshal(body, &w.wtData)
 	if err != nil {
 		return err
 	}
 
-	if cacheTimeout > 0 {
-		w.env.Cache().Set(url, string(body), cacheTimeout)
-	}
 	return nil
 }
 
@@ -74,12 +59,6 @@ func (w *Wakatime) getURL() (string, error) {
 	tmpl := &template.Text{
 		Template: url,
 		Context:  w,
-		Env:      w.env,
 	}
 	return tmpl.Render()
 }
-
-func (w *Wakatime) Init(props properties.Properties, env runtime.Environment) {
-	w.props = props
-	w.env = env
-}
